#!/usr/bin/env node --require dotenv/config
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const mongodb_1 = require("./mongodb");
const compile_1 = require("./compile");
const options_1 = require("./options");
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        // Load configuration file
        const opts = options_1.loadConfig();
        // Get schemas for all collections from the MongoDB server
        const schemas = yield mongodb_1.getDatabaseSchemas(opts.mongodbUri, opts.mongodbDatabase);
        console.log("Generating typescript types for MongoDB collection schemas");
        yield Promise.all(schemas.map(({ schema, collectionName }) => __awaiter(this, void 0, void 0, function* () {
            console.log((!schema ? "-" : "OK").padEnd(4), collectionName);
            // Do nothing when a collection has no schema
            if (!schema)
                return;
            const filename = typeof schema.title === "string" ? schema.title : null;
            if (!filename)
                throw new Error("A schema title is required");
            if (!fs_1.default.existsSync(opts.out)) {
                fs_1.default.mkdirSync(opts.out, { recursive: true });
            }
            const destination = path_1.default.join(opts.out, filename) + ".ts";
            const output = yield compile_1.compileBSON(schema, Object.assign(Object.assign({}, opts), { prettier: yield options_1.prettierOptions(destination) }));
            fs_1.default.writeFileSync(destination, output);
        })));
    });
}
main().catch(console.error);
//# sourceMappingURL=cli.js.map